import { unref } from 'vue';
import { FormSchema } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';
import { useLocale } from '/@/locales/useLocale';
import { RouteTypeStatus } from '/@/api/tigerapi/mes/router';

const { t } = useI18n();
const { getLocale } = useLocale();

export const formSchema: FormSchema[] = [
  {
    field: 'ROT_CODE',
    label: '工艺路线编码',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'ROT_NAME',
    label: '工艺路线名称',
    required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'ROT_TYPE',
    label: t('工艺路线类型'),
    component: 'ApiSelect',
    colProps: { span: 24 },
    componentProps: {
      api: RouteTypeStatus,
      resultField: 'Data',
      labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
      valueField: 'Value',
      // onChange: (e, v) => {
      //   alert(e)
      //   console.log('ApiSelect====>:', e, v);
      // },
    },
  },
  {
    field: 'ROT_VER',
    label: '工艺路线版本',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
  {
    field: 'IS_ACTIVE',
    label: '是否启用(Y/N)',
    required: true,
    component: 'Select',
    colProps: { span: 24 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
];
